@@ -15,14 +15,11 @@
 """Rikai Feature Store
 """
 from rikai.conf import *
-from rikai.numpy import array, empty, wrap
 from rikai.spark.sql.codegen import mlflow_logger as mlflow
 
 from .__version__ import version
 
 __all__ = [
-    "array",
-    "empty",
     "get_option",
     "mlflow",
     "options",
@@ -30,5 +27,4 @@ __all__ = [
     "reset_option",
     "set_option",
     "version",
-    "wrap",
 ]
