@@ -18,7 +18,9 @@ from typing import Optional
 
 import torch
 
+from rikai.mixin import Pretrained
 from rikai.spark.sql.model import ModelSpec, ModelType
+from rikai.spark.sql.codegen.dummy import DummyModelSpec
 
 __all__ = ["TorchModelType"]
 
@@ -31,11 +33,17 @@ class TorchModelType(ModelType, ABC):
         self.spec: Optional[ModelSpec] = None
 
     def load_model(self, spec: ModelSpec, **kwargs):
-        self.model = spec.load_model()
+        self.spec = spec
+        if isinstance(spec, DummyModelSpec):
+            if isinstance(self, Pretrained):
+                self.model = self.pretrained_model()
+            else:
+                raise ValueError("Missing model URI")
+        else:
+            self.model = self.spec.load_model()
         self.model.eval()
         if "device" in kwargs:
             self.model.to(kwargs.get("device"))
-        self.spec = spec
 
     # Release GPU memory
     # https://blog.paperspace.com/pytorch-memory-multi-gpu-debugging/?ref=tfrecipes
