@@ -12,14 +12,22 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from .torchvision import ObjectDetectionModelType
+import torchvision
+
+from rikai.mixin import Pretrained
+from rikai.pytorch.models.torchvision import ObjectDetectionModelType
 
 __all__ = ["MODEL_TYPE"]
 
 
-class FasterRCNNModelType(ObjectDetectionModelType):
+class FasterRCNNModelType(ObjectDetectionModelType, Pretrained):
     def __init__(self):
         super().__init__("fasterrcnn_resnet50_fpn")
 
+    def pretrained_model(self):
+        return torchvision.models.detection.fasterrcnn_resnet50_fpn(
+            pretrained=True
+        )
+
 
 MODEL_TYPE = FasterRCNNModelType()
