@@ -12,14 +12,20 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from .torchvision import ObjectDetectionModelType
+import torchvision
+
+from rikai.mixin import Pretrained
+from rikai.pytorch.models.torchvision import ObjectDetectionModelType
 
 __all__ = ["MODEL_TYPE"]
 
 
-class SSDModelType(ObjectDetectionModelType):
+class SSDModelType(ObjectDetectionModelType, Pretrained):
     def __init__(self):
         super().__init__("SSD")
 
+    def pretrained_model(self):
+        return torchvision.models.detection.ssd.ssd300_vgg16(pretrained=True)
+
 
 MODEL_TYPE = SSDModelType()
