@@ -11,24 +11,30 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
+
 """Custom Mlflow model logger to make sure models have the right logging for
 Rikai SQL ML
 """
+
+import os
+import tempfile
 import warnings
 from typing import Any, Optional
 
-CONF_MLFLOW_TRACKING_URI = "rikai.sql.ml.registry.mlflow.tracking_uri"
+CONF_MLFLOW_TRACKING_URI = "spark.rikai.sql.ml.registry.mlflow.tracking_uri"
 CONF_MLFLOW_OUTPUT_SCHEMA = "rikai.output.schema"
 CONF_MLFLOW_SPEC_VERSION = "rikai.spec.version"
 CONF_MLFLOW_PRE_PROCESSING = "rikai.transforms.pre"
 CONF_MLFLOW_POST_PROCESSING = "rikai.transforms.post"
 CONF_MLFLOW_MODEL_FLAVOR = "rikai.model.flavor"
+CONF_MLFLOW_MODEL_TYPE = "rikai.model.type"
 CONF_MLFLOW_ARTIFACT_PATH = "rikai.model.artifact_path"
 
 
 class MlflowLogger:
     """
     An alternative model logger for use during training instead of the vanilla
+    mlflow logger.
 
     """
 
@@ -44,15 +50,47 @@ class MlflowLogger:
         self.spec_version = MlflowLogger._CURRENT_MODEL_SPEC_VERSION
         self.flavor = flavor
 
+    def _log_tensorflow_model(
+        self,
+        model: Any,
+        artifact_path: str,
+        registered_model_name: str,
+        **kwargs,
+    ):
+        import tensorflow as tf
+
+        try:
+            import mlflow
+        except ImportError as e:
+            raise ImportError(
+                "Couldn't import mlflow. Please make sure to "
+                "`pip install mlflow` explicitly or install "
+                "the correct extras like `pip install rikai[mlflow]`"
+            ) from e
+
+        with tempfile.TemporaryDirectory() as tmp_dir:
+
+            tf.saved_model.save(model, tmp_dir)
+
+            mlflow.tensorflow.log_model(
+                tf_saved_model_dir=tmp_dir,
+                tf_meta_graph_tags=[tf.saved_model.SERVING],
+                tf_signature_def_key=next(iter(model.signatures.keys())),
+                artifact_path=artifact_path,
+                registered_model_name=registered_model_name,
+                **kwargs,
+            )
+
     def log_model(
         self,
         model: Any,
         artifact_path: str,
-        schema: str,
+        schema: Optional[str] = None,
         pre_processing: Optional[str] = None,
         post_processing: Optional[str] = None,
         registered_model_name: Optional[str] = None,
         customized_flavor: Optional[str] = None,
+        model_type: Optional[str] = None,
         **kwargs,
     ):
         """Convenience function to log the model with tags needed by rikai.
@@ -72,26 +110,30 @@ class MlflowLogger:
             Full python module path of the post-processing transforms
         registered_model_name: str, default None
             Model name in the mlflow model registry
+        model_type : str
+            Model type
         kwargs: dict
             Passed to `mlflow.<flavor>.log_model`
 
+
         Examples
         --------
-        # import mlflow.pytorch  <= vanilla mlflow usage
-        import rikai.mlflow
 
-        # Log PyTorch model
-        with mlflow.start_run() as run:
+        .. code-block:: python
 
-            # Training loop
-            # ...
+            import rikai.mlflow
+
+            # Log PyTorch model
+            with mlflow.start_run() as run:
+
+                # Training loop
+                # ...
+
+                # Assume `model` is the trained model from the training loop
+                rikai.mlflow.pytorch.log_model(model, "model",
+                        model_type="ssd",
+                        registered_model_name="MyPytorchModel")
 
-            # Assume `model` is the trained model from the training loop
-            rikai.mlflow.pytorch.log_model(model, "model",
-                      schema=rikai.contrib.torch.transforms.fasterrcnn_resnet50_fpn.OUTPUT_SCHEMA,
-                      pre_processing="rikai.contrib.torch.transforms.fasterrcnn_resnet50_fpn.pre_processing",
-                      post_processing="rikai.contrib.torch.transforms.fasterrcnn_resnet50_fpn.post_processing",
-                      registered_model_name="MyPytorchModel")
 
         For more details see `mlflow docs <https://www.mlflow.org/docs/latest/python_api/mlflow.pytorch.html#mlflow.pytorch.log_model>`_.
         """  # noqa E501
@@ -108,23 +150,38 @@ class MlflowLogger:
 
         # no need to set the tracking uri here since this is intended to be
         # called inside the training loop within mlflow.start_run
-        getattr(mlflow, self.flavor).log_model(
-            model,
-            artifact_path,
-            registered_model_name=registered_model_name,
-            **kwargs,
-        )
+        if self.flavor == "tensorflow":
+            self._log_tensorflow_model(
+                model,
+                artifact_path,
+                registered_model_name=registered_model_name,
+                **kwargs,
+            )
+        else:
+            getattr(mlflow, self.flavor).log_model(
+                model,
+                artifact_path,
+                registered_model_name=registered_model_name,
+                **kwargs,
+            )
+
         tags = {
             CONF_MLFLOW_SPEC_VERSION: MlflowLogger._CURRENT_MODEL_SPEC_VERSION,
             CONF_MLFLOW_MODEL_FLAVOR: customized_flavor
             if customized_flavor
             else self.flavor,
+            CONF_MLFLOW_MODEL_TYPE: model_type,
             CONF_MLFLOW_OUTPUT_SCHEMA: schema,
             CONF_MLFLOW_PRE_PROCESSING: pre_processing,
             CONF_MLFLOW_POST_PROCESSING: post_processing,
             CONF_MLFLOW_ARTIFACT_PATH: artifact_path,
         }
-        for k in (CONF_MLFLOW_PRE_PROCESSING, CONF_MLFLOW_POST_PROCESSING):
+        for k in (
+            CONF_MLFLOW_PRE_PROCESSING,
+            CONF_MLFLOW_POST_PROCESSING,
+            CONF_MLFLOW_MODEL_TYPE,
+            CONF_MLFLOW_OUTPUT_SCHEMA,
+        ):
             if not tags[k]:
                 del tags[k]
                 warnings.warn(
@@ -158,6 +215,6 @@ class MlflowLogger:
                 )
 
 
-KNOWN_FLAVORS = ["pytorch", "sklearn"]
+KNOWN_FLAVORS = ["pytorch", "sklearn", "tensorflow"]
 for flavor in KNOWN_FLAVORS:
     globals()[flavor] = MlflowLogger(flavor)
